##  IT Components in Scope
**Note**
SAP LeanIX reserves the right to change the scope of the catalog at any given time.
The following fact sheet subtype categories, serving as the interface between applications and providers, fall within the scope of catalog items defined as IT components:
  * Software: Major and minor versions of commercial and open-source software products relevant to enterprise architecture and technology risk management with significant lifecycles (for example, Oracle Database, Microsoft Window Server, Red Hat Enterprise Linux, PostgreSQL). In addition, technology product lines or tech stacks without specific versioning and lifecycle information are also included (for example, Angular).
  * PaaS: Platform as a Service (PaaS) offering deployment environments in the cloud (for example, Google App Engine, Heroku, Salesforce).
  * IaaS: Infrastructure as a Service (IaaS) cloud computing service (for example, Amazon Web Services (AWS) EC2, Microsoft Azure Virtual Machines).
  * SaaS: Software as a Service (SaaS) is in most cases an application. It will be accepted if it represents the hosting or if the SaaS application can be used as a component of a larger application (for example, Adobe Systems Adobe Admin Console, SAP LeanIX Enterprise Architecture Management SaaS Hosting).
  * Hardware components
  * AI models: Software components that implement artificial intelligence techniques, including machine learning, natural language processing, computer vision, and other forms of advanced analytics. AI models are used in applications to automate decision-making, pattern recognition, forecasting, and other predictive or generative tasks. AI models may be consumed directly as software artifacts, through APIs, or as integral parts of SaaS, PaaS, or custom technology stacks.
